@@ -1,4 +1,11 @@
-from .graph_operations import cleanup, getpath, subset_tree, attach_tree, extend_tips
+from .graph_operations import (
+    cleanup,
+    getpath,
+    subset_tree,
+    attach_tree,
+    extend_tips,
+    simplify,
+)
 from .graph_fitting import tree, curve, circle
 from .root import root, roots
 from .pseudotime import pseudotime, rename_milestones
@@ -17,3 +24,4 @@ from .bifurcation_tools import test_fork, branch_specific, activation, activatio
 from .conversion import cellrank_to_tree
 from .linearity_deviation import linearity_deviation
 from .dendrogram import dendrogram
+from .covariate import test_covariate, test_association_covariate
